@@ -132,7 +132,7 @@ def warn_eventlet_not_patched(expected_patched_modules=None,
 def is_monkey_patched(module):
     """Determines safely is eventlet patching for module enabled or not
     :param module: String, module name
-    :return Bool, True if module is patched, False otherwise
+    :return Bool: True if module is patched, False otherwise
     """
 
     if _patcher is None:
@@ -159,6 +159,9 @@ class _Event(object):
     isSet = is_set
 
     def set(self):
+        if self._set:
+            self._event.reset()
+
         self._set = True
         self._event.send(True)
 
@@ -169,7 +172,7 @@ class _Event(object):
 
 
 def Event():
-    if EVENTLET_AVAILABLE:
+    if is_monkey_patched("thread"):
         return _Event()
     else:
         return threading.Event()
